@@ -24,7 +24,7 @@
 #include <stdio.h>
 
 /* the next line is just so that I can use "c6.n" instead of "coxfit6.n", etc*/
-#define c6 coxfit6  
+/*#define c6 coxfit6  */
 static void update(int j, int upper);
 static double dsum1, dsum2;
 static int nvar3;
@@ -546,5 +546,3 @@ static void update(int j, int upper) {
     for (k=j; k<c6.bstop[j]; k++) c6.dlag2[j][k] = dsum2;
     for (k=c6.nsparse; k<nvar3; k++)   c6.dlag2[k][j]=c6.dsum3[k-c6.nsparse];
     }
-
-#undef c6
